import { shell } from "./shell";
import { existDirectory } from "./filesystem";
/**
 * gitコマンドを生成する
 * @param pwd コマンド実行ディレクトリ
 */
export const createCommand = (pwd) => {
    /**
     * @param args `git`コマンドの引数
     * @param cwd `git`コマンド実行ディレクトリ
     */
    const git = (args, cwd = pwd) => {
        console.log("Command: " + "git " + args);
        return shell("git " + args, cwd);
    };
    return {
        getBranch: (cwd) => git("symbolic-ref --short HEAD", cwd),
        getLatestCommitDate: (cwd) => git(`log --pretty=format:"%ad" -1`, cwd),
        getHeadCommitSha: (cwd) => git("rev-parse HEAD", cwd),
        clone: ({ owner, repo, branch, baseUrl, baseSshUrl, protocol, outputDir, cwd }) => {
            if (existDirectory(outputDir)) {
                throw new Error(`Already exist directory: "${outputDir}`);
            }
            if (protocol === "ssh") {
                return git(`clone -b ${branch} ${baseSshUrl}:${owner}/${repo} ${outputDir}`, cwd);
            }
            return git(`clone -b ${branch} ${baseUrl}/${owner}/${repo} ${outputDir}`, cwd);
        },
        getStatus: () => git("status"),
        push: (remote, branch) => git(`push ${remote} ${branch}`),
        commit: (message) => git(`commit -m '${message}' --no-verify`),
        addAll: () => git("add -A"),
    };
};
